[Mulgara-svn] r1562 - trunk/src/jar/resolver-spi/java/org/mulgara/resolver/spi

pag at mulgara.org pag at mulgara.org
Fri Feb 27 06:53:53 UTC 2009


Author: pag
Date: 2009-02-26 22:53:53 -0800 (Thu, 26 Feb 2009)
New Revision: 1562

Modified:
   trunk/src/jar/resolver-spi/java/org/mulgara/resolver/spi/Statements.java
Log:
Added constants for subject/predicate/object variable names, plus some formatting cleanups

Modified: trunk/src/jar/resolver-spi/java/org/mulgara/resolver/spi/Statements.java
===================================================================
--- trunk/src/jar/resolver-spi/java/org/mulgara/resolver/spi/Statements.java	2009-02-27 06:52:40 UTC (rev 1561)
+++ trunk/src/jar/resolver-spi/java/org/mulgara/resolver/spi/Statements.java	2009-02-27 06:53:53 UTC (rev 1562)
@@ -30,6 +30,7 @@
 // Local packages
 import org.mulgara.query.Cursor;
 import org.mulgara.query.TuplesException;
+import org.mulgara.query.Variable;
 import org.mulgara.store.nodepool.NodePool;
 
 /**
@@ -46,26 +47,28 @@
  * @licence <a href="{@docRoot}/../../LICENCE">Mozilla Public License v1.1</a>
  */
 
-public interface Statements extends Cursor
-{
-  /**
-   * Stopgap measure until the stringpool gets a <q>no match</q> value.
-   */
+public interface Statements extends Cursor {
+
+  /** A variable for the subject position in a triple */
+  static final Variable SUBJECT = new Variable("subject");
+
+  /** A variable for the predicate position in a triple */
+  static final Variable PREDICATE = new Variable("predicate");
+
+  /** A variable for the object position in a triple */
+  static final Variable OBJECT = new Variable("object");
+
+
+  /** Stopgap measure until the stringpool gets a <q>no match</q> value. */
   static final long NONE = NodePool.NONE;
 
-  /**
-   * Return the subject node of the current triple.
-   */
+  /** Return the subject node of the current triple. */
   public long getSubject() throws TuplesException;
 
-  /**
-   * Return the predicate node of the current triple.
-   */
+  /** Return the predicate node of the current triple. */
   public long getPredicate() throws TuplesException;
 
-  /**
-   * Return the object node of the current triple.
-   */
+  /** Return the object node of the current triple. */
   public long getObject() throws TuplesException;
 
   public Object clone();




More information about the Mulgara-svn mailing list